@@ -1,5 +1,4 @@
-# __init__.py for computerjanitorapp
-# Copyright (C) 2008, 2009  Canonical, Ltd.
+# Copyright (C) 2008, 2009, 2010  Canonical, Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,24 +12,29 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""computerjanitorapp module."""
 
-VERSION = "1.13.3"
+from __future__ import absolute_import, unicode_literals
+
+__metaclass__ = type
+__all__ = [
+    '__version__',
+    'setup_gettext',
+    ]
 
 
-# Set up gettext. This needs to be before the import statements below
-# so that if any modules call it right after importing, they find
-# setup_gettext.
+__version__ = '2.0.4'
 
+
+# Set up gettext.
 def setup_gettext():
     """Set up gettext for a module.
 
-    Return a method to be used for looking up translations. Usage:
-
-      import computerjanitorapp
-      _ = computerjanitorapp.setup_gettext()
+    Return a method to be used for looking up translations.  Usage:
 
+    >>> import computerjanitorapp
+    >>> _ = computerjanitorapp.setup_gettext()
     """
-
     import gettext
     import os
 
@@ -38,11 +42,3 @@ def setup_gettext():
     localedir = os.environ.get('LOCPATH', None)
     t = gettext.translation(domain, localedir=localedir, fallback=True)
     return t.ugettext
-
-
-from app import Application
-from ui import UserInterface
-from ui_cli import CommandLineUserInterface
-from ui_gtk import GtkUserInterface
-from state import State
-from terminalsize import get_terminal_size
