@@ -83,8 +83,7 @@ class UnsupportedPackagesPlugin(computerjanitor.Plugin):
     
     def has_installed_rdepends(self, cache, pkg): # pragma: no cover
         """Does a package have any installed reverse dependencies?"""
-        installed = [x for x in cache if x.isInstalled]
-        for x in installed:
+        for x in self.installed:
             if pkg.name in self.installed_deps(x):
                 return True
         return False
@@ -100,12 +99,12 @@ class UnsupportedPackagesPlugin(computerjanitor.Plugin):
     	    return True
         if pkg.installed.downloadable or pkg.candidate.downloadable:
             return True
-        if not pkg.isAutoRemovable: # pragma: no cover
+        # if not pkg.isAutoRemovable: # pragma: no cover
             # This is a kludge to guess to exclude manually installed
             # packages (such as third-party one, or locally created ones)
             # are not considered cruft. This means, however, that this
             # plugin degenerates to the autoremovable plugin.
-            return True
+            # return True
         if len(pkg._pkg.VersionList) > 1:
             # if there is just a single version and that is not
             # downloadable anymore, then its cruft this avoids cases
@@ -119,12 +118,14 @@ class UnsupportedPackagesPlugin(computerjanitor.Plugin):
         # this ensure that we do not remove manually installed application
         # (like skype). its a workaround for the lack of proper knowning
         # where a package comes from (archive, PPA, ...) once its installed
-        if not pkg._pcache._depcache.IsAutoInstalled(pkg._pkg):
-            return True
+#        if not pkg._pcache._depcache.IsAutoInstalled(pkg._pkg):
+#            return True
         return False
 
     def get_cruft(self):
+        self.installed = [x for x in self.app.apt_cache if x.isInstalled]
         for pkg in self.app.apt_cache:
             if not self.is_supported(pkg):
                 if not self.has_installed_rdepends(self.app.apt_cache, pkg):
                      yield computerjanitor.PackageCruft(pkg, self.description)
+
